==> kdevelop-4.5.90.tar.xz: kdevelop-4.5.90/projectbuilders/cmakebuilder/kdevcmakebuilder.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=CMake Project Builder
Name[bs]=CMake graditelj projekta
Name[ca]=Constructor de projecte CMake
Name[ca@valencia]=Constructor de projecte CMake
Name[cs]=Překladač projektů CMake
Name[da]=Bygning af CMake-projekter
Name[de]=Ersteller für CMake-Projekte
Name[el]=Κατασκευαστής έργων CMake
Name[en_GB]=CMake Project Builder
Name[es]=Constructor de proyecto CMake
Name[et]=CMake'i projektiehitaja
Name[fi]=CMake-projektikäännin
Name[fr]=Constructeur de projets CMake
Name[ga]=Tógálaí Tionscadal CMake
Name[gl]=Construtor de proxecto con CMake
Name[hu]=CMake projektfordító
Name[it]=Compilatore progetto CMake
Name[ja]=CMake プロジェクトビルダー
Name[kk]=CMake жоба құрастырғышы
Name[km]=កម្មវិធី​ស្ថាបនា​គម្រោង CMake
Name[nb]=CMake prosjektbygger
Name[nds]=CMake-Projektbuumoduul
Name[nl]=CMake-projectbouwer
Name[pl]=Budowanie projektu za pomocą CMake
Name[pt]=Construtor de Projectos do CMake
Name[pt_BR]=Compilador de projeto do CMake
Name[ru]=Сборщик проектов CMake
Name[sk]=Prekladač projektov CMake
Name[sl]=Izgrajevalnik projekta CMake
Name[sv]=CMake-projektbyggverktyg
Name[tr]=CMake Proje Oluşturucu
Name[ug]=CMake قۇرۇلۇش ياسىغۇچ
Name[uk]=Інструмент збирання проектів CMake
Name[x-test]=xxCMake Project Builderxx
Name[zh_CN]=CMake 工程构建器
Name[zh_TW]=CMake 專案建立器
GenericName=Project Builder
GenericName[bs]=Graditelj projekta
GenericName[ca]=Constructor de projectes
GenericName[ca@valencia]=Constructor de projectes
GenericName[cs]=Překladač projektů
GenericName[da]=Bygning af projekter
GenericName[de]=Projektersteller
GenericName[el]=Κατασκευαστής έργου
GenericName[en_GB]=Project Builder
GenericName[es]=Constructor de proyectos
GenericName[et]=Projektiehitaja
GenericName[fi]=Projektikäännin
GenericName[fr]=Constructeur de projets
GenericName[ga]=Tógálaí Tionscadal
GenericName[gl]=Construtor de proxectos
GenericName[hu]=Projektfordító
GenericName[it]=Compilatore progetto
GenericName[ja]=プロジェクトビルダー
GenericName[kk]=Жоба құрастырғышы
GenericName[km]=កម្មវិធី​ស្ថាបនា​គម្រោង
GenericName[nb]=Prosjektbygger
GenericName[nds]=Projektbuumoduul
GenericName[nl]=Projectbouwer
GenericName[pl]=Budowanie projektu
GenericName[pt]=Construtor de Projectos
GenericName[pt_BR]=Compilador de projetos
GenericName[ru]=Сборщик проектов
GenericName[sk]=Prekladač projektov
GenericName[sl]=Izgrajevalnik projektov
GenericName[sv]=Projektbyggverktyg
GenericName[tr]=Proje Oluşturucu
GenericName[ug]=قۇرۇلۇش ياسىغۇچ
GenericName[uk]=Збирання проектів
GenericName[x-test]=xxProject Builderxx
GenericName[zh_CN]=工程构建器
GenericName[zh_TW]=專案編譯器
Comment=Builds CMake Projects
Comment[bs]=Gradi CMake projekte
Comment[ca]=Construeix projectes CMake
Comment[ca@valencia]=Construeix projectes CMake
Comment[cs]=Překládá projekty CMake
Comment[da]=Bygger CMake-projekter
Comment[de]=Erstellt CMake-Projekte
Comment[el]=Κατασκευή έργων CMake
Comment[en_GB]=Builds CMake Projects
Comment[es]=Construye proyectos CMake
Comment[et]=CMake'i projektide ehitamine
Comment[fa]=پروژه‌های CMake را می‌سازد
Comment[fi]=Kääntää CMake-projekteja
Comment[fr]=Compile les projets CMake
Comment[ga]=Tóg Tionscadail CMake
Comment[gl]=Elabora proxectos de CMake
Comment[hi]=सीमेक परियोजना बनाता है
Comment[hne]=सीमेक परियोजना बनाथे 
Comment[hu]=CMake projektek fordítása
Comment[it]=Compila i progetti CMake
Comment[ja]=CMake プロジェクトをビルドします
Comment[kk]=CMake жобаларын құрастыру
Comment[km]=ស្ថាបនា​គម្រោង CMake
Comment[ko]=CMake 프로젝트를 빌드합니다
Comment[lv]=Būvē CMake projektus
Comment[nb]=Bygger CMake-prosjekter
Comment[nds]=Buut CMake-Projekten
Comment[nl]=Bouwt CMake-projecten
Comment[pl]=Buduje projekty za pomocą CMake
Comment[pt]=Compila Projectos do CMake
Comment[pt_BR]=Compila projetos CMake
Comment[ru]=Собирает проекты CMake
Comment[sk]=Prekladá projekty CMake
Comment[sl]=Izgradi projekte CMake
Comment[sv]=Bygger CMake-projekt
Comment[tr]=CMake Projelerini Derler
Comment[ug]=CMake قۇرۇلۇشلىرىنى ياساش
Comment[uk]=Збирає проекти CMake
Comment[x-test]=xxBuilds CMake Projectsxx
Comment[zh_CN]=构建 CMake 工程
Comment[zh_TW]=建立 CMake 專案
Icon=system-run
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcmakebuilder
X-KDE-PluginInfo-Name=KDevCMakeBuilder
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-ProjectBuilder=CMake
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectBuilder
X-KDevelop-IRequired=org.kdevelop.IOutputView,org.kdevelop.IMakeBuilder
X-KDevelop-Mode=NoGUI

==> kdevelop-4.7.4.tar.xz: kdevelop-4.7.4/projectbuilders/cmakebuilder/kdevcmakebuilder.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=CMake Project Builder
Name[bs]=CMake graditelj projekta
Name[ca]=Constructor de projecte CMake
Name[ca@valencia]=Constructor de projecte CMake
Name[cs]=Překladač projektů CMake
Name[da]=Bygning af CMake-projekter
Name[de]=Ersteller für CMake-Projekte
Name[el]=Κατασκευαστής έργων CMake
Name[en_GB]=CMake Project Builder
Name[es]=Constructor de proyecto CMake
Name[et]=CMake'i projektiehitaja
Name[fi]=CMake-projektikäännin
Name[fr]=Constructeur de projets CMake
Name[ga]=Tógálaí Tionscadal CMake
Name[gl]=Construtor de proxecto con CMake
Name[hu]=CMake projektfordító
Name[it]=Generatore progetto CMake
Name[ja]=CMake プロジェクトビルダー
Name[kk]=CMake жоба құрастырғышы
Name[km]=កម្មវិធី​ស្ថាបនា​គម្រោង CMake
Name[nb]=CMake prosjektbygger
Name[nds]=CMake-Projektbuumoduul
Name[nl]=CMake-projectbouwer
Name[pl]=Budowanie projektu za pomocą CMake
Name[pt]=Construtor de Projectos do CMake
Name[pt_BR]=Compilador de projeto do CMake
Name[ru]=Сборщик проектов CMake
Name[sk]=Prekladač projektov CMake
Name[sl]=Izgrajevalnik projekta CMake
Name[sv]=CMake-projektbyggverktyg
Name[tr]=CMake Proje Oluşturucu
Name[ug]=CMake قۇرۇلۇش ياسىغۇچ
Name[uk]=Інструмент збирання проектів CMake
Name[x-test]=xxCMake Project Builderxx
Name[zh_CN]=CMake 工程构建器
Name[zh_TW]=CMake 專案建立器
GenericName=Project Builder
GenericName[bs]=Graditelj projekta
GenericName[ca]=Constructor de projectes
GenericName[ca@valencia]=Constructor de projectes
GenericName[cs]=Překladač projektů
GenericName[da]=Bygning af projekter
GenericName[de]=Projektersteller
GenericName[el]=Κατασκευαστής έργου
GenericName[en_GB]=Project Builder
GenericName[es]=Constructor de proyectos
GenericName[et]=Projektiehitaja
GenericName[fi]=Projektikäännin
GenericName[fr]=Constructeur de projets
GenericName[ga]=Tógálaí Tionscadal
GenericName[gl]=Construtor de proxectos
GenericName[hu]=Projektfordító
GenericName[it]=Compilatore progetto
GenericName[ja]=プロジェクトビルダー
GenericName[kk]=Жоба құрастырғышы
GenericName[km]=កម្មវិធី​ស្ថាបនា​គម្រោង
GenericName[nb]=Prosjektbygger
GenericName[nds]=Projektbuumoduul
GenericName[nl]=Projectbouwer
GenericName[pl]=Budowanie projektu
GenericName[pt]=Construtor de Projectos
GenericName[pt_BR]=Compilador de projetos
GenericName[ru]=Сборщик проектов
GenericName[sk]=Prekladač projektov
GenericName[sl]=Izgrajevalnik projektov
GenericName[sv]=Projektbyggverktyg
GenericName[tr]=Proje Oluşturucu
GenericName[ug]=قۇرۇلۇش ياسىغۇچ
GenericName[uk]=Збирання проектів
GenericName[x-test]=xxProject Builderxx
GenericName[zh_CN]=工程构建器
GenericName[zh_TW]=專案編譯器
Comment=Builds CMake Projects
Comment[bs]=Gradi CMake projekte
Comment[ca]=Construeix projectes CMake
Comment[ca@valencia]=Construeix projectes CMake
Comment[cs]=Překládá projekty CMake
Comment[da]=Bygger CMake-projekter
Comment[de]=Erstellt CMake-Projekte
Comment[el]=Κατασκευή έργων CMake
Comment[en_GB]=Builds CMake Projects
Comment[es]=Construye proyectos CMake
Comment[et]=CMake'i projektide ehitamine
Comment[fa]=پروژه‌های CMake را می‌سازد
Comment[fi]=Kääntää CMake-projekteja
Comment[fr]=Compile les projets CMake
Comment[ga]=Tóg Tionscadail CMake
Comment[gl]=Elabora proxectos de CMake
Comment[hi]=सीमेक परियोजना बनाता है
Comment[hne]=सीमेक परियोजना बनाथे 
Comment[hu]=CMake projektek fordítása
Comment[it]=Compila i progetti CMake
Comment[ja]=CMake プロジェクトをビルドします
Comment[kk]=CMake жобаларын құрастыру
Comment[km]=ស្ថាបនា​គម្រោង CMake
Comment[ko]=CMake 프로젝트를 빌드합니다
Comment[lv]=Būvē CMake projektus
Comment[nb]=Bygger CMake-prosjekter
Comment[nds]=Buut CMake-Projekten
Comment[nl]=Bouwt CMake-projecten
Comment[pl]=Buduje projekty za pomocą CMake
Comment[pt]=Compila Projectos do CMake
Comment[pt_BR]=Compila projetos CMake
Comment[ru]=Собирает проекты CMake
Comment[sk]=Prekladá projekty CMake
Comment[sl]=Izgradi projekte CMake
Comment[sv]=Bygger CMake-projekt
Comment[tr]=CMake Projelerini Derler
Comment[ug]=CMake قۇرۇلۇشلىرىنى ياساش
Comment[uk]=Збирає проекти CMake
Comment[x-test]=xxBuilds CMake Projectsxx
Comment[zh_CN]=构建 CMake 工程
Comment[zh_TW]=建立 CMake 專案
Icon=system-run
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcmakebuilder
X-KDE-PluginInfo-Name=KDevCMakeBuilder
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-ProjectBuilder=CMake
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectBuilder
X-KDevelop-IRequired=org.kdevelop.IOutputView,org.kdevelop.IMakeBuilder
X-KDevelop-Mode=NoGUI
